==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/Stacked100SplineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedSplineSeries } from "./StackedSplineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedSplineSeriesView } from "./StackedSplineSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100SplineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeries, _super);
    function Stacked100SplineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100SplineSeries.$;
        return _this;
    }
    Stacked100SplineSeries.prototype.bx = function () {
        return new Stacked100SplineSeriesView(this);
    };
    Stacked100SplineSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.uq = a;
    };
    Stacked100SplineSeries.prototype.get_tp = function () {
        return true;
    };
    Stacked100SplineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.mi(false);
    };
    Stacked100SplineSeries.prototype.t5 = function () {
        _super.prototype.t5.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100SplineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.sk;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100SplineSeries.$t = markType(Stacked100SplineSeries, 'Stacked100SplineSeries', StackedSplineSeries.$, [IStacked100Series_$type]);
    return Stacked100SplineSeries;
}(StackedSplineSeries));
export { Stacked100SplineSeries };
/**
 * @hidden
 */
var Stacked100SplineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeriesView, _super);
    function Stacked100SplineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100SplineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c0.qd = Defaults.e;
        }
    };
    Stacked100SplineSeriesView.$t = markType(Stacked100SplineSeriesView, 'Stacked100SplineSeriesView', StackedSplineSeriesView.$);
    return Stacked100SplineSeriesView;
}(StackedSplineSeriesView));
export { Stacked100SplineSeriesView };

==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/Stacked100SplineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedSplineSeries } from "./StackedSplineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedSplineSeriesView } from "./StackedSplineSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100SplineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeries, _super);
    function Stacked100SplineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100SplineSeries.$;
        return _this;
    }
    Stacked100SplineSeries.prototype.bx = function () {
        return new Stacked100SplineSeriesView(this);
    };
    Stacked100SplineSeries.prototype.l2 = function (a) {
        _super.prototype.l2.call(this, a);
        this.uu = a;
    };
    Stacked100SplineSeries.prototype.get_tt = function () {
        return true;
    };
    Stacked100SplineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.ml(false);
    };
    Stacked100SplineSeries.prototype.t9 = function () {
        _super.prototype.t9.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100SplineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.so;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100SplineSeries.$t = markType(Stacked100SplineSeries, 'Stacked100SplineSeries', StackedSplineSeries.$, [IStacked100Series_$type]);
    return Stacked100SplineSeries;
}(StackedSplineSeries));
export { Stacked100SplineSeries };
/**
 * @hidden
 */
var Stacked100SplineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeriesView, _super);
    function Stacked100SplineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100SplineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c0.qh = Defaults.e;
        }
    };
    Stacked100SplineSeriesView.$t = markType(Stacked100SplineSeriesView, 'Stacked100SplineSeriesView', StackedSplineSeriesView.$);
    return Stacked100SplineSeriesView;
}(StackedSplineSeriesView));
export { Stacked100SplineSeriesView };
